@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12825 2021-03-31 13:28:58Z Lavender $
+# $Id: __init__.py 12853 2021-04-22 07:31:24Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2021-03-31 21:28:58 +0800 (Wed, 31 Mar 2021) $
-# $Revision: 12825 $
+# $Date: 2021-04-22 15:31:24 +0800 (週四, 22 四月 2021) $
+# $Revision: 12853 $
 
 # Avoid conflict with Iuno.cloud.logging moudle.
 from __future__ import absolute_import
@@ -325,15 +325,16 @@ def tryGet(methodName, backends, preferred=None, *args, **kws):
             return HostInfo(backend, info)
     return None
 
-def attachURLs(settings, urlpatterns, services=SERVICES):
+def attachURLs(settings, urlpatterns, services=SERVICES, excludeApps=[]):
                     
     for service in services:
-        try:
-            serviceAttachURLs = classForName('Iuno.cloud.%s.attachURLs' % service)
-        except ImportError as ex:
-            logger.warn('%s can not be imported: %s' % (service, str(ex)))
-            continue
-        
-        serviceAttachURLs(settings, urlpatterns)
+        if not "Iuno.cloud.%s" % service in excludeApps:
+            try:
+                serviceAttachURLs = classForName('Iuno.cloud.%s.attachURLs' % service)
+            except ImportError as ex:
+                logger.warn('%s can not be imported: %s' % (service, str(ex)))
+                continue
+            
+            serviceAttachURLs(settings, urlpatterns)
                     
     
