@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 13097 2021-07-23 06:08:15Z Mint $
+# $Id: Backends.py 13177 2021-08-04 01:21:35Z Mint $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Mint $
-# $Date: 2021-07-23 14:08:15 +0800 (週五, 23 七月 2021) $
-# $Revision: 13097 $
+# $Date: 2021-08-04 09:21:35 +0800 (週三, 04 八月 2021) $
+# $Revision: 13177 $
 
 import re
 import os
@@ -28,13 +28,6 @@ from django.conf import settings
 from django.core.exceptions import PermissionDenied
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
-
-from Iuppiter.DjangoUtil import DJANGO_VERSION
-if(DJANGO_VERSION >= 30000):
-    from django.contrib.auth.backends import BaseBackend
-else:
-    BaseBackend = object
-    
 DEFAULT_TRAC_AUTH_URL = getattr(settings, 
     'DEFAULT_TRAC_AUTH_URL', 'https://code.nuwainfo.com/aec359bc3cfadb7504f26461a4c06625')
 DEFAULT_TRAC_AUTH_USERNAME = getattr(settings, 'DEFAULT_TRAC_AUTH_USERNAME', 'Deploy')
@@ -44,7 +37,7 @@ SET_TRAC_LOGIN_AS_SUPERUSER = getattr(settings, "SET_TRAC_LOGIN_AS_SUPERUSER", F
 
 USER_DATA_PATTERN = "#\s+?(\w+):\s+?(\{.+\}?)"
   
-class TracBackend(BaseBackend):
+class TracBackend(ModelBackend):
 
     def check(self, username, password, tracAuthURL=DEFAULT_TRAC_AUTH_URL, 
         tracUsername=DEFAULT_TRAC_AUTH_USERNAME, tracPassword=DEFAULT_TRAC_AUTH_PASSWORD):
